import * as React from 'react';
import { createPortal, render, unmountComponentAtNode } from 'react-dom';
import './style.scss';
var close = function (id) {
    var div = document.getElementById(id);
    if (div && div.classList.contains('x-message--show')) {
        div.classList.remove('x-message--show');
        div.classList.add('x-message--hide');
        setTimeout(function () {
            if (div && div.parentNode) {
                unmountComponentAtNode(div);
                div.parentNode.removeChild(div);
            }
        }, 280);
    }
};
var Message = function (params, duration) {
    if (duration === void 0) { duration = 2000; }
    var divs = document.querySelectorAll('.x-message.x-message--show');
    if (divs.length) {
        Message.close();
    }
    var div = document.createElement('div');
    div.classList.add('x-message', 'x-message--show');
    var id = "j-x-message--" + new Date().valueOf() + "-" + Math.floor(Math.random() * 999999);
    div.id = id;
    var layoutFooter = document.querySelector('.x-app > .x-app-footer');
    if (layoutFooter && layoutFooter.clientHeight > 0) {
        div.classList.add('x-message--behind-footer');
        layoutFooter.before(div);
    }
    else {
        document.body.appendChild(div);
    }
    var _params = { title: '' };
    if (typeof params === 'string') {
        _params.title = params;
        _params.feedback = '知道了';
        _params.onFeedbackClick = function () { return close(id); };
    }
    else {
        _params.title = params.title;
        _params.desc = params.desc;
        _params.feedback = params.feedback || '知道了';
        _params.onFeedbackClick = function () {
            params.onFeedbackClick && params.onFeedbackClick();
            close(id);
        };
    }
    render(createPortal(React.createElement("div", { className: "x-message__inner" },
        React.createElement("div", { className: "info" },
            React.createElement("h6", null, _params.title),
            _params.desc && React.createElement("p", null, _params.desc)),
        _params.feedback && React.createElement("button", { onClick: _params.onFeedbackClick }, _params.feedback)), div), div);
    setTimeout(close, Math.max(duration, 500), id);
};
// 清除全部message
Message.close = function () {
    var divs = document.querySelectorAll('.x-message.x-message--show');
    if (divs.length) {
        divs.forEach(function (div) { return close(div.id); });
    }
};
export default Message;
